@@ -48,12 +48,6 @@
 {% endmacro %}
 
 
-{% macro firebolt__current_timestamp() %}
-
-    NOW()
-{% endmacro %}
-
-
 {% macro firebolt__alter_column_type(relation, column_name, new_column_type) -%}
   {# Stub: alter statements not currently available in Firebolt. #}
   {% call statement('alter_column_type') %}
@@ -153,16 +147,16 @@
     Args: relation: dbt Relation
   -#}
   {% set sql %}
-
-  SELECT * FROM {{ relation }} LIMIT 1
+    SELECT column_name, data_type from information_schema.columns
+    WHERE table_name = '{{ relation }}'
   {% endset %}
-  {#- add_query returns a cursor object. The names and types of the table named
-      by `relation` have to be converted to the correct type. -#}
-  {%- set (conn, cursor) = adapter.add_query(sql = sql, abridge_sql_log=True) -%}
-  {%- set ret_val = adapter.sdk_column_list_to_firebolt_column_list(
-                        cursor.description
-                    ) -%}
-  {{ return(ret_val) }}
+  {%- set result = run_query(sql) -%}
+  {% set columns = [] %}
+  {% for row in result %}
+    {% do columns.append(adapter.get_column_class().from_description(row['column_name'],
+                         adapter.resolve_special_columns(row['data_type']))) %}
+  {% endfor %}
+  {% do return(columns) %}
 {% endmacro %}
 
 
@@ -183,7 +177,7 @@
              '{{ relation.schema }}' AS "schema",
              'table' AS type
         FROM information_schema.tables
-      UNION
+      UNION ALL
       SELECT '{{ relation.database }}' AS "database",
              table_name AS "name",
              '{{ relation.schema }}' AS "schema",
@@ -271,14 +265,3 @@
      This will be replaced by `CREATE OR REPLACE`. #}
   {{ adapter.drop_relation(relation) }}
 {% endmacro %}
-
-
-{# TODO: Do we still need this?
-   See https://packboard.atlassian.net/browse/FIR-12156 #}
-{% macro firebolt__snapshot_string_as_time(timestamp) -%}
-  {% call statement('timestamp', fetch_result=True) %}
-
-      SELECT CAST('{{ timestamp }}' AS DATE)
-  {% endcall %}
-  {{ return(load_result('timestamp').table) }}
-{% endmacro %}
